==> james-project-3.7.6-source-release.zip: james-project/server/container/guice/common/src/main/java/org/apache/james/utils/GuiceProbeProvider.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.utils;

import java.util.Map;
import java.util.Optional;
import java.util.Set;
import java.util.function.Function;

import javax.inject.Inject;

import com.google.common.base.Preconditions;
import com.google.common.collect.ImmutableMap;

public class GuiceProbeProvider {
    private final Map<Class<GuiceProbe>, GuiceProbe> registry;

    @SuppressWarnings("unchecked")
    @Inject
    public GuiceProbeProvider(Set<GuiceProbe> guiceProbes) {
        this.registry = guiceProbes.stream()
            .collect(ImmutableMap.toImmutableMap(guiceProbe -> (Class<GuiceProbe>) guiceProbe.getClass(), Function.identity()));
    }

    @SuppressWarnings("unchecked")
    public <T extends GuiceProbe> T getProbe(Class<T> clazz) {
        Preconditions.checkNotNull(clazz);
        return Optional.ofNullable(registry.get(clazz))
            .map(probe -> (T) probe)
            .orElseThrow(() -> new RuntimeException("No probe registered for class: " + clazz));
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/common/src/main/java/org/apache/james/utils/GuiceProbeProvider.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.utils;

import java.util.Map;
import java.util.Optional;
import java.util.Set;
import java.util.function.Function;

import jakarta.inject.Inject;

import com.google.common.base.Preconditions;
import com.google.common.collect.ImmutableMap;

public class GuiceProbeProvider {
    private final Map<Class<GuiceProbe>, GuiceProbe> registry;

    @SuppressWarnings("unchecked")
    @Inject
    public GuiceProbeProvider(Set<GuiceProbe> guiceProbes) {
        this.registry = guiceProbes.stream()
            .collect(ImmutableMap.toImmutableMap(guiceProbe -> (Class<GuiceProbe>) guiceProbe.getClass(), Function.identity()));
    }

    @SuppressWarnings("unchecked")
    public <T extends GuiceProbe> T getProbe(Class<T> clazz) {
        Preconditions.checkNotNull(clazz);
        return Optional.ofNullable(registry.get(clazz))
            .map(probe -> (T) probe)
            .orElseThrow(() -> new RuntimeException("No probe registered for class: " + clazz));
    }
}
